#
# spec file for package python-py-cpuinfo
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-py-cpuinfo
Version:        3.1.0
Release:        lp150.1.3
Summary:        Get CPU info with pure Python
License:        MIT
Group:          Development/Languages/Python
Url:            https://github.com/workhorsy/py-cpuinfo
Source:         https://files.pythonhosted.org/packages/source/p/py-cpuinfo/py-cpuinfo-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires(post): update-alternatives
Requires(preun): update-alternatives
%python_subpackages

%description
Py-cpuinfo gets CPU info with pure Python. Py-cpuinfo should work
without any extra programs or libraries, beyond what your OS
provides. It does not require any compilation(C/C++, assembly, et
cetera) to use. It works on Linux, OS X, Windows, BSD, Solaris,
Cygwin, Haiku, and BeagleBone. It currently only works on X86 and some
ARM CPUs.

These approaches are used for getting info:
 1. Windows Registry (Windows)
 2. /proc/cpuinfo (Linux)
 3. sysctl (OS X)
 4. dmesg (Unix/Linux)
 5. isainfo and kstat (Solaris)
 6. cpufreq-info (BeagleBone)
 7. lscpu (Unix/Linux)
 8. sysinfo (Haiku)
 9. Querying the CPUID register (Intel X86 CPUs)

%prep
%setup -q -n py-cpuinfo-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Prepare for update-alternatives usage
%python_clone -a %{buildroot}%{_bindir}/cpuinfo

%if %{with tests}
%check
%python_exec test_suite.py
%endif

%post
%python_install_alternative cpuinfo

%preun
%python_uninstall_alternative cpuinfo

%files %{python_files}
%defattr(-,root,root,-)
%doc README.rst LICENSE ChangeLog
%python_alternative %{_bindir}/cpuinfo
%{python_sitelib}/*

%changelog
* Wed Apr 19 2017 toddrme2178@gmail.com
- Update to 3.1.0
  * Fixed Bug #63: Include py-cpuinfo version in output
  * Fixed Bug #29: Missing AVX2 CPU flag on OS X
  * Fixed Bug #41: Broken on Odroid XU3 armhf ARM 32bit
  * Fixed Bug #61: Not working on RHEL7.3 ppc64le
  * Fixed Bug #56: Not working on Red Flag Linux ppc64le
  * Fixed Bug #55: Not working on Fedora 24 ppc64le
- Update to 3.0.0
  * Change API to hide low level functions
  * Fixed Bug #51: Combine data from all sources instead of picking one
  * Fixed Bug #59: Not working on OS X 10.12 Sierra
  * Fixed Bug #58: Change version number format
  * Fixed Bug #60: Not working on ARM64 odroid-c2
- Update to 0.2.7
  * Fixed Bug #53: CPUID breaks test suite when SE Linux is on (Fedora 25)
  * Fixed Bug #54: CPUID breaks when it returns nothing (Fedora 26)
- Update to 0.2.6
  * New release because pypi does not allow deleting broken uploads
- Update to 0.2.5
  * New release because pypi does not allow deleting broken uploads
- Update to 0.2.4
  * Fixed Bug #35: Add basic documentation
  * Fixed Bug #36: Make test suite test real functions too
  * Fixed Bug #38: get_cpu_info_from_cpuid breaks with Python3
  * Fixed Bug #47: Include sysctl leaf7_features and extfeatures flags
- Implement single-spec version
* Tue Aug 16 2016 toddrme2178@gmail.com
- Initial python 2 version.
* Tue Aug 16 2016 toddrme2178@gmail.com
- Implement update-alternatives
* Tue Jul  5 2016 arun@gmx.de
- initial version
